@@ -175,6 +175,9 @@ qnetd_ipc_init(struct qnetd_instance *instance)
 
 	if (unix_socket_ipc_init(&instance->local_ipc,
 	    instance->advanced_settings->local_socket_file,
+	    instance->advanced_settings->set_local_socket_umask,
+	    instance->advanced_settings->local_socket_umask,
+	    instance->advanced_settings->local_socket_gid,
 	    instance->advanced_settings->local_socket_backlog,
 	    instance->advanced_settings->ipc_max_clients,
 	    instance->advanced_settings->ipc_max_receive_size,
