@@ -32,11 +32,13 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <stdio.h>
 #include <assert.h>
-#include <string.h>
-#include <math.h>
 #include <errno.h>
+#include <grp.h>
+#include <math.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include "utils.h"
 
@@ -48,6 +50,11 @@ main(void)
 	double dbl;
 	double dbli;
 	char buf[32];
+	int set_umask;
+	mode_t umask;
+	gid_t gid;
+	struct group *grp;
+	char *s;
 
 	assert(utils_strtonum("0", 0, 100, &ll) == 0);
 	assert(ll == 0);
@@ -80,6 +87,45 @@ main(void)
 	assert(utils_strtonum("test", -1000, 1000, &ll) == -1);
 	assert(utils_strtonum("12a", -1000, 1000, &ll) == -1);
 
+	assert(utils_strtonum_base("0", 0, 0100, 8, &ll) == 0);
+	assert(ll == 0);
+
+	assert(utils_strtonum_base("100", 0, 0100, 8, &ll) == 0);
+	assert(ll == 0100);
+
+	assert(utils_strtonum_base("0100", 0, 0100, 8, &ll) == 0);
+	assert(ll == 0100);
+
+	assert(utils_strtonum_base("101", 0, 0100, 8, &ll) != 0);
+	assert(utils_strtonum_base("0", 01, 0100, 8, &ll) != 0);
+	assert(utils_strtonum_base("8", 0, 0100, 8, &ll) != 0);
+
+	for (lli = 0; lli <= 0777; lli++) {
+		assert(snprintf(buf, sizeof(buf), "%llo", lli) > 0);
+
+		assert(utils_strtonum_base(buf, 0, 0777, 8, &ll) == 0);
+		assert(ll == lli);
+	}
+
+	assert(utils_strtonum_base("0", 0, 0100, 16, &ll) == 0);
+	assert(ll == 0);
+
+	assert(utils_strtonum_base("100", 0, 0x100, 16, &ll) == 0);
+	assert(ll == 0x100);
+
+	assert(utils_strtonum_base("0x100", 0, 0x100, 16, &ll) == 0);
+	assert(ll == 0x100);
+
+	assert(utils_strtonum_base("101", 0, 0x0100, 16, &ll) != 0);
+	assert(utils_strtonum_base("0", 0x1, 0x0100, 16, &ll) != 0);
+
+	for (lli = 0; lli <= 0x100; lli++) {
+		assert(snprintf(buf, sizeof(buf), "%llx", lli) > 0);
+
+		assert(utils_strtonum_base(buf, 0, 0x100, 16, &ll) == 0);
+		assert(ll == lli);
+	}
+
 	assert(utils_parse_bool_str("on") == 1);
 	assert(utils_parse_bool_str("yes") == 1);
 	assert(utils_parse_bool_str("1") == 1);
@@ -137,5 +183,47 @@ main(void)
 	assert(utils_strtod("inf", -1000, 1000, &dbl) == -1);
 	assert(utils_strtod("nan", -1000, 1000, &dbl) == -1);
 
+	assert(utils_parse_umask("0", &set_umask, &umask) == 0);
+	assert(set_umask == 1 && umask == 0);
+
+	assert(utils_parse_umask("02", &set_umask, &umask) == 0);
+	assert(set_umask == 1 && umask == 02);
+
+	assert(utils_parse_umask("777", &set_umask, &umask) == 0);
+	assert(set_umask == 1 && umask == 0777);
+
+	assert(utils_parse_umask("", &set_umask, &umask) == 0);
+	assert(set_umask == 0);
+
+	assert(utils_parse_umask("02", &set_umask, &umask) == 0);
+	assert(set_umask == 1 && umask == 02);
+
+	assert(utils_parse_umask("string", &set_umask, &umask) == -1);
+	assert(utils_parse_umask("888", &set_umask, &umask) == -1);
+	assert(utils_parse_umask("8", &set_umask, &umask) == -1);
+	assert(utils_parse_umask("unset", &set_umask, &umask) == -1);
+
+	assert(utils_get_group_gid("0", &gid) == 0);
+	assert(gid == 0);
+
+	assert(utils_get_group_gid("", &gid) == 0);
+	assert(gid == -1);
+
+	assert(utils_get_group_gid("1000", &gid) == 0);
+	assert(gid == 1000);
+
+	assert(utils_get_group_gid("-1", &gid) == 0);
+	assert(gid == -1);
+
+	assert((grp = getgrgid(0)) != NULL);
+	assert((s = strdup(grp->gr_name)) != NULL);
+
+	assert(utils_get_group_gid(s, &gid) == 0);
+	assert(gid == 0);
+
+	free(s);
+
+	assert(utils_get_group_gid("qdevicetestnonexistinggroup", &gid) == -1);
+
 	return (0);
 }
