@@ -40,8 +40,10 @@
 #include <err.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <grp.h>
 #include <inttypes.h>
 #include <libgen.h>
+#include <limits.h>
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -51,6 +53,8 @@
 
 #include "utils.h"
 
+#define UTILS_GID_DETERMINE_MAX_SIZE	65536
+
 /*
  * Check string to value on, off, yes, no, 0, 1. Return 1 if value is on, yes or 1, 0 if
  * value is off, no or 0 and -1 otherwise.
@@ -212,8 +216,8 @@ utils_fd_set_non_blocking(int fd)
  * Safer wrapper of strtoll. Return 0 on success, otherwise -1.
  */
 int
-utils_strtonum(const char *str, long long int min_val, long long int max_val,
-    long long int *res)
+utils_strtonum_base(const char *str, long long int min_val, long long int max_val,
+    int base, long long int *res)
 {
 	long long int tmp_ll;
 	char *ep;
@@ -224,7 +228,7 @@ utils_strtonum(const char *str, long long int min_val, long long int max_val,
 
 	errno = 0;
 
-	tmp_ll = strtoll(str, &ep, 10);
+	tmp_ll = strtoll(str, &ep, base);
 	if (ep == str || *ep != '\0' || errno != 0) {
 		return (-1);
 	}
@@ -238,6 +242,17 @@ utils_strtonum(const char *str, long long int min_val, long long int max_val,
 	return (0);
 }
 
+/*
+ * Shortcut for decimal utils_strtonum_base
+ */
+int
+utils_strtonum(const char *str, long long int min_val, long long int max_val,
+    long long int *res)
+{
+
+	return (utils_strtonum_base(str, min_val, max_val, 10, res));
+}
+
 /*
  * Safer wrapper of strtod. Return 0 on success, otherwise -1.
  */
@@ -267,3 +282,106 @@ utils_strtod(const char *str, double min_val, double max_val,
 
 	return (0);
 }
+
+/*
+ * Check if string is empty and set set_umask to 0, or parse string
+ * as umask octal number and set set_umask to 1 and umask value.
+ * Return 0 on success, otherwise -1.
+ */
+int
+utils_parse_umask(const char *str, int *set_umask, mode_t *umask)
+{
+	long long int tmpll;
+
+	if (strcmp(str, "") == 0) {
+		*set_umask = 0;
+	} else {
+		if (utils_strtonum_base(str, 0, S_IRWXU|S_IRWXG|S_IRWXO, 8, &tmpll) == -1) {
+			return (-1);
+		}
+
+		*set_umask = 1;
+		*umask = (mode_t)tmpll;
+	}
+
+	return (0);
+}
+
+/*
+ * Get gid of group with grp_name name. On success, 0 is returned and
+ * gid contains valid group id or -1 if grp_name is empty string or -1.
+ * In case of error including group doesn't exist -1 is returned and
+ * gid is not changed.
+ */
+int
+utils_get_group_gid(const char *grp_name, gid_t *gid)
+{
+	long long int tmpll;
+	char *grp_buf, *tmp_buf;
+	long int grp_buf_size;
+	int res;
+	struct group grp, *grp_res;
+	int ret;
+
+	ret = 0;
+
+	if (strcmp(grp_name, "") == 0) {
+		*gid = (gid_t)-1;
+
+		return (0);
+	}
+
+	if (utils_strtonum(grp_name, -1, UINT_MAX, &tmpll) == 0) {
+		*gid = (gid_t)tmpll;
+
+		return (0);
+	}
+
+	grp_buf_size = sysconf(_SC_GETGR_R_SIZE_MAX);
+	if (grp_buf_size == -1) {
+		grp_buf_size = 4096;
+	}
+
+	grp_buf = malloc(grp_buf_size);
+	if (grp_buf == NULL) {
+		return (-1);
+	}
+
+	while ((res = getgrnam_r(grp_name, &grp, grp_buf, grp_buf_size, &grp_res)) == ERANGE) {
+		grp_buf_size *= 2;
+
+		if (grp_buf_size > UTILS_GID_DETERMINE_MAX_SIZE) {
+			ret = -1;
+
+			goto exit_free_grp_buf;
+		}
+
+		tmp_buf = realloc(grp_buf, grp_buf_size);
+		if (tmp_buf == NULL) {
+			ret = -1;
+
+			goto exit_free_grp_buf;
+		}
+
+		grp_buf = tmp_buf;
+	}
+
+	if (res != 0) {
+		ret = -1;
+
+		goto exit_free_grp_buf;
+	}
+
+	if (grp_res == NULL) {
+		ret = -1;
+
+		goto exit_free_grp_buf;
+	} else {
+		*gid = grp.gr_gid;
+	}
+
+exit_free_grp_buf:
+	free(grp_buf);
+
+	return (ret);
+}
