@@ -65,9 +65,17 @@ extern int		utils_fd_set_non_blocking(int fd);
 extern int		utils_strtonum(const char *str, long long int min_val,
     long long int max_val, long long int *res);
 
+extern int		utils_strtonum_base(const char *str, long long int min_val,
+    long long int max_val, int base, long long int *res);
+
 extern int		utils_strtod(const char *str, double min_val, double max_val,
     double *res);
 
+extern int		utils_parse_umask(const char *str, int *set_umask,
+    mode_t *umask);
+
+extern int		utils_get_group_gid(const char *grp_name, gid_t *gid);
+
 #ifdef __cplusplus
 }
 #endif
